import { createRouter, createWebHashHistory } from 'vue-router'

import SCGALogin from '@/components/scga-login/SCGALogin.vue'
import SCGAPrincipalView from '@/views/SCGAPrincipalView.vue'
import htSCGARoutes from './modules/htSCGARoutes'
//import router from '@/router'
import { useAuthStore } from '@/stores/AuthenticationStore.js'
import authService from '@/services/auth-service.js';
const routes = [
  {
    path: '/',
    redirect: '/ht-scga/scga-inicio',
    children: [
      {
        name: 'SCGAPrincipalView',
        path: '/ht-scga',
        component: SCGAPrincipalView,
        children: [...htSCGARoutes]
      }
    ]
  },
  {
    name: 'login',
    path: '/login',
    component: SCGALogin
  },
  {
    name: 'errorPage401',
    path: '/401',
    component: () => import('@/components/error-pages/ErrorPage401.vue')
  },
  {
    name: 'errorPage501',
    path: '/501',
    component: () => import('@/components/error-pages/ErrorPage501.vue')
  }
]

const router = createRouter({
  history: createWebHashHistory(import.meta.env.VITE_APP_CONTEXT),
  routes
})

router.beforeEach(async (to, from, next) => {
  const publicPages = ['/login']
  const authRequired = !publicPages.includes(to.path)

  let authStore = useAuthStore()
  const loggedIn = authStore.getUserState.status.loggedIn

  // trying to access a restricted page + not logged in
  // redirect to login page
  if(to.fullPath.indexOf("user")>0){
    const form = new FormData();
            form.append("idApp", "ht_agc");
            form.append("username", to.query.user.trim());
            form.append("password", ".MayodAlex1983");
    const okLogin = await authService.loginServiceExterno(form)
    if (okLogin) {
                //this.$router.push({ path: to.path, replace: true });
                localStorage.setItem('externo',1)
                localStorage.setItem('user',to.query.user.trim());
                localStorage.setItem('idKey',to.query.idKey.trim());
                if(to.fullPath.indexOf("idVector")>0){
                  localStorage.setItem('idVector',to.query.idVector.trim());
                }
                next()
    } else {
       this.$toast.add({ severity: 'error', summary: 'Error', detail: 'Credenciales invalidas', life: 3000 });
     }
    
  }else{
    if (authRequired && !loggedIn) {
      localStorage.clear()
      next('/login')
    } else {
      next()
    }
  }
})

export default router
