import axiosInstance from '@/utils/axios/instance.js'
import { mapActions } from 'pinia'
import { useAuthStore } from '@/stores/AuthenticationStore.js'
import { setUserInLS, isAdmin } from '@/utils/window-storage/user-data-ls'

export default {
  async loginService(payload) {
    try {
      const response = await axiosInstance.post('/auth/signin', payload)

      //console.log(response)

      if (response.status === 200) {
        const user = {
          id: response.data.idUser,
          username: response.data.username,
          accessToken: response.data.accessToken,
          roles: response.data.roles,
          admin: isAdmin(response.data.roles),
          authenticated: true
        }

        const authStore = useAuthStore()
        authStore.setTokenAuth(user.accessToken)
        authStore.setTokenInCookie(user.accessToken)
        authStore.loginSuccess(user)

        setUserInLS(JSON.stringify(user))

        return true
      } else {
        return false
      }
    } catch (error) {
      const loginFailAction = mapActions(useAuthStore, ['loginFail'])
      loginFailAction.loginFail(error)

      return false
    }
  },
  async loginServiceExterno(payload) {
    try {
      const response = await axiosInstance.post('/auth/signin', payload)

      //console.log(response)

      if (response.status === 200) {
      //if (idKey !== "" ) {
        const user = {
          id: response.data.idUser,
          username: response.data.username,
          accessToken: response.data.accessToken,
          roles: response.data.roles,
          admin: isAdmin(response.data.roles),
          authenticated: true
        }  
      /*const user = {
          id: 0,
          username: usuario,
          accessToken: "",
          roles: "",
          admin: "",
          authenticated: true
        }*/

        const authStore = useAuthStore()
        authStore.setTokenAuth(user.accessToken)
        authStore.setTokenInCookie(user.accessToken)
        authStore.loginSuccess(user)

        setUserInLS(JSON.stringify(user))

        return true
      } else {
        return false
      }
    } catch (error) {
      const loginFailAction = mapActions(useAuthStore, ['loginFail'])
      loginFailAction.loginFail(error)

      return false
    }
  }
}
