import { defineStore } from 'pinia'
import { getUserFromLS, removeUserFromLS } from '@/utils/window-storage/user-data-ls'
import {
  getTokenFromCookie,
  setTokenInCookie,
  removeTokenFromCookie
} from '@/utils/window-storage/token-cookie.js'
import router from '@/router'

const user = getUserFromLS()
const initialState = user
  ? { status: { loggedIn: true }, user }
  : { status: { loggedIn: false }, user }

export const useAuthStore = defineStore('auth', {
  state: () => ({
    userState: initialState,
    tokenAuth: getTokenFromCookie()
  }),
  getters: {
    getStoreAccessToken: (state) => state.tokenAuth,
    getUserState: (state) => state.userState,
    getUsername: (state) => state.userState.user.username
  },
  actions: {
    //Arrow functions don't have their own bindings to this
    setTokenAuth(tokenAuth) {
      this.tokenAuth = tokenAuth
    },
    setTokenInCookie(accessToken) {
      setTokenInCookie(accessToken)
    },
    loginSuccess(user) {
      this.userState.status.loggedIn = true
      this.userState.user = user
    },
    loginFail() {
      this.userState.status.loggedIn = false
      this.userState.user = null
    },
    logout() {
      removeUserFromLS()
      this.userState.status.loggedIn = false
      this.userState.user = null
      removeTokenFromCookie()
      this.removeTokenAuth('')
      localStorage.clear()
      router.push({ path: '/login', replace: true })
    },
    removeTokenAuth(valor) {
      this.userState.tokenAuth = valor
    }
  }
})
