

export function generateDropdownOptions(
  rawData,
  dynamicKey,
  dynamicOptionLabel
) {
  return rawData.map((item) => {
    return {
      key: item[dynamicKey],
      optionLabel: item[dynamicOptionLabel],
    };
  });
}


/**
 * Este metodo se utliza para actualizar el valor seleccionado de un 
 * dropdown en un formulario donde el valor precargado es llave foranea 
 * de otra tabla y el nombre es el mismo que la llave primaria a la que hace
 * referencia.
 *
 * @param itemData Datos donde se encuentra el id a actualizar, con este id
 * se llamará un servicio para encontrar el valor de ese id en otra tabla
 * @param appForm Formulario a actualizar
 * @param {dropdownName, key, optionLabel, service} Metadatos para actualizar
 * @returns appForm uptaded
 */

export async function updateDropdownValue(
  itemData,
  appForm,
  { dropdownName, key, optionLabel, service }
) {
  try {
    const idKeyValue = itemData[key];

    const catalogosResponse = await service.getById(idKeyValue);
    const index = appForm.findIndex((item) => item.name === dropdownName);
    if (index !== -1) {
      appForm[index].value = {
        key: catalogosResponse.data[key],
        optionLabel: catalogosResponse.data[optionLabel],
      };
    }
  } catch (error) {
    console.error("Error updating dropdown value:", error);
  }
}


/**
 * Este metodo se utliza para actualizar el valor seleccionado de un 
 * dropdown en un formulario 
 *
 * @param itemData Datos donde del valor a actualizar
 * @param appForm Formulario a actualizar
 * @param {dropdownName, key, optionLabel} Metadatos para actualizar
 * @returns appForm uptaded
 */
export async function updateDropdownValueObject(
  item,
  appForm,
  { dropdownName, key, optionLabel }
) {
  try {
    const index = appForm.findIndex((item) => item.name === dropdownName);
    if (index !== -1) {
      appForm[index].value = {
        key: item[key],
        optionLabel: item[optionLabel],
      };
    }
  } catch (error) {
    console.error("Error updating dropdown value:", error);
  }
}


