import { convertToCamelCase } from '@/utils/TextUtils.js'

export function updateAppFormValues(appForm, list) {
  appForm.forEach((item) => {
    const camelCaseName = item.name.toUpperCase()
    if (item.type === 'check') {
      if (typeof list[camelCaseName] == 'string') {
        item.value = list[camelCaseName] === '1'
      } else if (typeof list[camelCaseName] == 'boolean') {
        item.value = list[camelCaseName]
      }
    } else if (item.type === 'calendar') {
      const fechDate=((list[camelCaseName]+"").substring(0,10)).split("/");
      //item.value = new Date(list[camelCaseName])
      item.value = new Date(fechDate[1] + '/' +fechDate[0] +'/' +fechDate[2])
    } else if (item.type === 'checks') {
      if (list[camelCaseName].length > 0) {
        let textValues = list[camelCaseName].split(',')
        let objectValues = item.options.filter((option) => textValues.includes(option.optionLabel))
        item.value = objectValues
        //console.log('checks', objectValues)
      } else {
        item.value = null
      }
    } else {
      item.value = list[camelCaseName]
    }
  })
}

export function buildFormData(appFormIn) {
  const appForm = JSON.parse(JSON.stringify(appFormIn))
  const appFormUpdated = updateCheckTypesValues(appForm)
  const form = new FormData()
  appFormUpdated.forEach((item) => {
    const { name, value, type } = item
    const cCName = convertToCamelCase(name)

    if (value !== null && typeof value === 'object') {
      if (value.hasOwnProperty('key')) {
        form.append(cCName, value.key)
      } else if (type === 'calendar') {
        form.append(cCName, value.toJSON())
      } else if (type === 'checks') {
        form.append(cCName, value.map((el) => el.key).join(','))
      } else if (type == 'file') {
        if (value.datafile) {
          let additional_info = {}
          additional_info.name = value.datafile.name
          additional_info.size = value.datafile.size
          additional_info.replace = value.replace
          additional_info.reference = item.ref
          form.append('files', value.datafile, JSON.stringify(additional_info))
        }
      } else {
        form.append(cCName, JSON.stringify(value))
      }
    } else {
      form.append(cCName, value == null ? '' : value) //en servidor llega como string "null";posteriormente buscar manera de solventar de una forma mas "eficiente"
    }
  })
  return form
}

export function buildModelJson(appFormIn) {
  const appForm = JSON.parse(JSON.stringify(appFormIn))
  const appFormUpdated = updateCheckTypesValues(appForm)
  const model = {}
 
  appFormUpdated.forEach((item) => {
    const { name, value, type } = item
    const cCName = name.toUpperCase()
    if (value !== null && typeof value === 'object') {
      if (value.hasOwnProperty('key')) {
        model[cCName] = value.key
      } else if (type === 'calendar') {
        model[cCName] = value
      } else if (type === 'checks') {
        model[cCName] = value.map((el) => el.key).join(',')
      } else {
        model[cCName] = JSON.stringify(value)
      }
    } else {
      model[cCName] = value
    }
  })
  return model
}

export function buildModelJsonForPBis(appFormIn) {
  const appForm = JSON.parse(JSON.stringify(appFormIn))
  const appFormUpdated = updateCheckTypesValues(appForm)
  const model = {}

  appFormUpdated.forEach((item) => {
    const { name, value, type } = item
    const cCName = name.toUpperCase()
    if (value !== null && typeof value === 'object') {
      if (value.hasOwnProperty('key')) {
        model[cCName] = value.key
      } else if (type === 'checks') {
        model[cCName] = value.map((el) => el.key).join(',')
      } else {
        model[cCName] = JSON.stringify(value)
      }
    } else if (type === 'calendar') {
      model[cCName] =`TO_DATE('${value}', 'YYYY-MM-DD"T"HH24:MI:SS".""ZZZZ"')` 
    }else if (type === 'inputtext' || type === 'textarea') {
      model[cCName] =`'${value}'` 
    }
    else {
      model[cCName] = value
    }
  })
  return model
}

function updateCheckTypesValues(appForm) {
  return appForm.map((item) => {
    if (item.type === 'check') {
      item.value = item.value ? '1' : '0'
    }
    return item
  })
}

export function formDataToJson(formData) {
  const params = new URLSearchParams(formData)
  const jsonData = {}

  for (const [key, value] of params) {
    jsonData[key] = value
  }

  return JSON.parse(JSON.stringify(jsonData))
}

export function printFormData(formData) {
  for (let [key, value] of formData.entries()) {
    //console.log(`${key}: ${value}`)
  }
}

export function disableFormElement(formData, name, value) {
  let indexElement = formData.findIndex((element) => {
    return element.name === name
  })

  formData[indexElement].disabled = value
}
