import axios from 'axios'
import bisTokenService from '@/services/bis/bisTokenService.js'
import { useAuthStore } from '@/stores/AuthenticationStore.js'

const axiosBisInstance = axios.create({
  baseURL: import.meta.env.VITE_APP_SERVER_APIBIS_RUTAC,
  //timeout: 30000
})

let isRefreshing = false

// Agregar un interceptor para las solicitudes
axiosBisInstance.interceptors.request.use(
  async (config) => {
    const token = await obtenerToken()
    config.headers.Authorization = `Bearer ${token}`
    return config
  },
  (error) => {
    return Promise.reject(error)
  }
)

// Agregar un interceptor para las respuestas
axiosBisInstance.interceptors.response.use(
  (response) => {
    return response
  },
  async (error) => {
    const originalRequest = error.config

    if (error.response.status === 401 && !isRefreshing) {
      isRefreshing = true

      const newToken = await obtenerNuevoToken()

      if (newToken) {
        axiosBisInstance.defaults.headers.common['Authorization'] = `Bearer ${newToken}`
        originalRequest.headers['Authorization'] = `Bearer ${newToken}`
        isRefreshing = false

        // Actualizar el token 
        //console.log("newToken:", newToken);
        const authStore = useAuthStore()
        authStore.setTokenAuth(newToken)

        return axiosBisInstance(originalRequest)
      }
    }
    return error
    //return Promise.reject(error)
  }
)

async function obtenerToken() {
  const authStore = useAuthStore()
  return authStore.tokenAuth // Obtener el token de la tienda de Pinia
}

async function obtenerNuevoToken() {
  return bisTokenService.obtenerToken()
}

export default axiosBisInstance


