import axios from "axios";
import { useAuthStore } from "@/stores/AuthenticationStore.js";


// create an axios instance
const service = axios.create({
  baseURL:
    import.meta.env.VITE_APP_SERVER_AUTH_API +
    "/" +
    import.meta.env.VITE_APP_SERVER_AUTH_API_CONTEXT,
  timeout: 30000,
});

// request interceptor
service.interceptors.request.use(
  (config) => {
    const authStore = useAuthStore();
    const userTokenAuth = authStore.getStoreAccessToken;
    if (userTokenAuth) {
      const token = "Bearer " + userTokenAuth;
      config.headers["Authorization"] = token;
    }
    return config;
  },
  (error) => {
    console.log(error); // debug
    return Promise.reject(error);
  }
);

// response interceptor
service.interceptors.response.use(
  
  (response) => {

    return response;
  },
  (error) => {
    console.log(
      "--------------------- Error interceptado --------------------- "
    );
    console.log(error);
    //Cerrar sesión si el estatus es no autorizado
    if (error.response && error.response.status === 401) {
      console.log("Auth error");
      const authStore = useAuthStore();
      authStore.logout();
    } else if (error.code === 'ERR_NETWORK') {
      console.log("Network error");
    }
    return Promise.reject(error);
  }
);

export default service;
