import SQLFactory from './SQLFactory'

export default class CrudGenerator {
  constructor(tableName, keyFieldName) {
    this.tableName = tableName
    this.keyFieldName = keyFieldName
  }

  // Método para crear un nuevo registro
  create(data) {
    const insertSQL = SQLFactory.createInsertSQL(this.tableName, this.keyFieldName, data)
    return insertSQL
  }

  // Método para generar una sentencia de lectura por ID
  getAll() {
    return `SELECT * FROM ${this.tableName}`
  }

  // Método para generar una sentencia de actualización por ID
  update(id, data) {
    const updateSQL = SQLFactory.createUpdateSQL(this.tableName, this.keyFieldName,id, data)
    return updateSQL
  }

  // Método para generar una sentencia de eliminación por ID
  delete(id) {
    return `DELETE FROM ${this.tableName}  WHERE ${this.keyFieldName} = ${id}`
  }

  // Método para generar una sentencia de lectura por ID
  getById(id) {
    return `SELECT * FROM ${this.tableName} WHERE ${this.keyFieldName} = ${id}`
  }

  // Método para generar una sentencia de lectura por ID
  getFiltered(id) {
    return `SELECT * FROM ${this.tableName} WHERE ${this.keyFieldName} = ${id}`
  }

  /*getByPageAndFilter(first, row, filterColumn, filterValue) {
    const selectSQL = SQLFactory.createSelectWithPaginationAndFilterSQL(this.tableName, first, row, filterColumn, filterValue);
    const countSQL = SQLFactory.createSelectCountForPagination(this.tableName, filterColumn, filterValue);
    
    return {selectSQL, countSQL};
  }*/
  getByPageAndFilter(first, rows, filterColumn, filterValue) {
    const filters = { [filterColumn]: filterValue }

    const selectSQL = SQLFactory.createSelectWithPaginationAndFilterSQL(
      this.tableName,
      first,
      rows,
      filters, null
    )
    const countSQL = SQLFactory.createSelectCountForPagination(this.tableName, filters, null)

    return { selectSQL, countSQL }
  }
  getByPageAndFilterAndForeingKey(first, row, filterColumn, filterValue, foreingKeyName, foreingKeyValue) {
    const filters = { [filterColumn]: filterValue }
    const foreingKeys = { [foreingKeyName]: foreingKeyValue }

    const selectSQL = SQLFactory.createSelectWithPaginationAndFilterSQL(
      this.tableName,
      first,
      row,
      filters,
      foreingKeys      
    )

    const countSQL = SQLFactory.createSelectCountForPagination(this.tableName, filters, foreingKeys)

    return { selectSQL, countSQL }
  }
  getByPageAndFilterAndForeingKeyBuilder(options) {
    const filters = { [options.filterColumn]: options.filterValue }
    const foreingKeys = { [options.foreingKeyName]: options.foreingKeyValue }
 
    const selectSQL = SQLFactory.createSelectWithPaginationAndFilterSQL(
      this.tableName,
      options.first,
      options.rows,
      filters,
      foreingKeys,
      options.orderColumns,
      options.orderType
    )
 
    const countSQL = SQLFactory.createSelectCountForPagination(this.tableName, filters, foreingKeys)
 
    return { selectSQL, countSQL }
  }
}
