export default class SQLFactory {
  // Método para generar sentencias SQL de inserción
  static createInsertSQL(tableName, keyFieldName, data) {
    // Lógica para generar la sentencia SQL de inserción
    return `INSERT INTO ${tableName} (${keyFieldName}, ${Object.keys(data).join(
      ', '
    )}) VALUES (SEC_${tableName}.NEXTVAL, ${Object.values(data)
      .map((value) => `${value}`)
      .join(', ')})`
  }

  // Método para generar sentencias SQL de actualización
  static createUpdateSQL(tableName, keyFieldName, id, data) {
    // Lógica para generar la sentencia SQL de actualización
    const setClause = Object.keys(data)
      .map((key) => `${key} = ${data[key]}`)
      .join(', ')
    return `UPDATE ${tableName} SET ${setClause}  WHERE ${keyFieldName} = ${id}`
  }

  // // Método para generar una sentencia SQL de consulta con paginación y filtros
  // static createSelectWithPaginationAndFilterSQL(tableName, first, rows, filterColumn, filterValue) {

  //   const baseSQL = `SELECT * FROM ${tableName}`
  //   let sql = baseSQL

  //   if (filterColumn && filterValue) {
  //     sql += ` WHERE lower(${filterColumn}) LIKE '%${filterValue.toLowerCase()}%'`
  //   }

  //   sql += ` OFFSET ${first} ROWS FETCH NEXT ${rows} ROWS ONLY`

  //   return sql
  // }

  // static createSelectCountForPagination(tableName,  filterColumn, filterValue) {

  //   const baseSQL = `SELECT count(*) as total FROM ${tableName}`
  //   let sql = baseSQL

  //   if (filterColumn && filterValue) {
  //     sql += ` WHERE lower(${filterColumn}) LIKE '%${filterValue.toLowerCase()}%'`
  //   }

  //   return sql
  // }

  // Método para generar una sentencia SQL de consulta con paginación y filtros
  static createSelectWithPaginationAndFilterSQL(tableName, first, rows, filters, foreingKeys,orderColumns,orderType) {
    const baseSQL = `SELECT * FROM ${tableName}`
    let sql = baseSQL
    let filterConditions = []
    let foreingKeysConditions = []

    if (filters && Object.keys(filters).length > 0) {
      Object.entries(filters).forEach(([column, value]) => {
        filterConditions.push(`lower(${column}) LIKE '%${value ? value.toLowerCase() : ''}%'`)
      })

      sql += ` WHERE ${filterConditions.join(' AND ')}`
    }

    if (foreingKeys && Object.keys(foreingKeys).length > 0) {
      Object.entries(foreingKeys).forEach(([foreingkey, value]) => {
        foreingKeysConditions.push(`${foreingkey} = ${value}`)
      })

      sql += ` AND ${foreingKeysConditions.join(' AND ')}`
    }

    if (orderColumns && orderType){
      sql += ` ORDER BY ${orderColumns} ${orderType} `
    }
    sql += ` OFFSET ${first} ROWS FETCH NEXT ${rows} ROWS ONLY`

    return sql
  }

  static createSelectCountForPagination(tableName, filters, foreingKeys) {
    const baseSQL = `SELECT count(*) as total FROM ${tableName}`
    let sql = baseSQL
    let filterConditions = []
    let foreingKeysConditions = []

    if (filters && Object.keys(filters).length > 0) {
      Object.entries(filters).forEach(([column, value]) => {
        filterConditions.push(`lower(${column}) LIKE '%${value ? value.toLowerCase() : ''}%'`)
      })

      sql += ` WHERE ${filterConditions.join(' AND ')}`
    }

    if (foreingKeys && Object.keys(foreingKeys).length > 0) {
      Object.entries(foreingKeys).forEach(([foreingkey, value]) => {
        foreingKeysConditions.push(`${foreingkey} = ${value}`)
      })

      sql += ` AND ${foreingKeysConditions.join(' AND ')}`
    }

    return sql
  }
}
